--- a/mmsharing/mmshengine/inc/musengsession.h Thu Jul 15 18:35:08 2010 +0300
+++ b/mmsharing/mmshengine/inc/musengsession.h Thu Aug 19 09:51:39 2010 +0300
@@ -83,13 +83,20 @@
IMPORT_C TBool AudioRoutingCanBeChanged() const;
/**
* Checks if audio output is BT
*
* @return ETrue if audio routing is BT
*/
- IMPORT_C TBool AudioOutputIsBT() const;
+ IMPORT_C TBool IsAudioRoutingHeadset() const;
/**
+ * Checks if audio routing is LoudSpeaker
+ *
+ * @return ETrue if audio routing is LoudSpeaker and
+ * currentMode != iAudioOutputAtStartup
+ */
+ IMPORT_C TBool IsAudioRoutingLoudSpeaker() const;
+ /**
* Activates/deactivates loadspeaker
*
* @param TBool Enable or disable loudspeaker
@@ -83,13 +83,20 @@
IMPORT_C TBool AudioRoutingCanBeChanged() const;
/**
- * Checks if audio output is BT
+ * Checks if audio routing is headset
*
@@ -83,13 +83,20 @@
*
- * @return ETrue if audio routing is BT
+ * @return ETrue if audio routing is headset
*/